@@ -1,8 +1,9 @@
 """Audio Read/Write Module
 """
 
-from . import ffmpegprocess, utils, configure, FFmpegError, probe, plugins
+from . import ffmpegprocess, utils, configure, FFmpegError, probe, plugins, caps
 from .utils import filter as filter_utils, log as log_utils
+import logging
 
 __all__ = ["create", "read", "write", "filter"]
 
@@ -57,9 +58,11 @@ def _run_read(
     else:
         out = ffmpegprocess.run(
             *args,
-            capture_log=None if show_log else False,
+            capture_log=None if show_log else True,
             **kwargs,
         )
+        if out.returncode:
+            raise FFmpegError(out.stderr, show_log)
 
     return rate, plugins.get_hook().bytes_to_audio(
         b=out.stdout, dtype=dtype, shape=(ac,), squeeze=False
@@ -107,18 +110,7 @@ def create(
 
     .. note:: Either `duration` or `nb_samples` filter options must be set.
 
-    Supported Audio Source Filters
-    ------------------------------
-
-    =============  ==============================================================================
-    filter name    description
-    =============  ==============================================================================
-    "aevalsrc"     an audio signal specified by an expression
-    "anoisesrc"    a noise audio signal
-    "sine"         audio signal made of a sine wave with amplitude 1/8
-    =============  ==============================================================================
-
-    https://ffmpeg.org/ffmpeg-filters.html#Audio-Sources
+    See https://ffmpeg.org/ffmpeg-filters.html#Audio-Sources for available video source filters
 
     ouptut data object is determined by the selected `bytes_to_audio` hook
 
@@ -185,11 +177,14 @@ def read(url, progress=None, show_log=None, **options):
     sample_fmt = options.get("sample_fmt", None)
     ac_in = ar_in = None
     if sample_fmt is None:
-        # use the same format as the input
-        info = probe.audio_streams_basic(url, 0)[0]
-        sample_fmt = info["sample_fmt"]
-        ac_in = info.get("ac", None)
-        ar_in = info.get("ar", None)
+        try:
+            # use the same format as the input
+            info = probe.audio_streams_basic(url, 0)[0]
+            sample_fmt = info["sample_fmt"]
+            ac_in = info.get("ac", None)
+            ar_in = info.get("ar", None)
+        except:
+            sample_fmt = 's16'
 
     input_options = utils.pop_extra_options(options, "_in")
     url, stdin, input = configure.check_url(
@@ -244,14 +239,16 @@ def write(url, rate_in, data, progress=None, overwrite=None, show_log=None, **op
     )
     configure.add_url(ffmpeg_args, "output", url, options)
 
-    ffmpegprocess.run(
+    out = ffmpegprocess.run(
         ffmpeg_args,
         input=plugins.get_hook().audio_bytes(obj=data),
         stdout=stdout,
         progress=progress,
         overwrite=overwrite,
-        capture_log=None if show_log else False,
+        capture_log=None if show_log else True,
     )
+    if out.returncode:
+        raise FFmpegError(out.stderr, show_log)
 
 
 def filter(expr, input_rate, input, progress=None, sample_fmt=None, **options):
