@@ -1,5 +1,6 @@
 from . import ffmpegprocess, utils, configure, FFmpegError, probe, plugins
 from .utils import filter as filter_utils, log as log_utils
+import logging
 
 __all__ = ["create", "read", "write", "filter"]
 
@@ -40,11 +41,11 @@ def _run_read(*args, shape=None, pix_fmt_in=None, s_in=None, show_log=None, **kw
     else:
         out = ffmpegprocess.run(
             *args,
-            capture_log=None if show_log else False,
+            capture_log=None if show_log else True,
             **kwargs,
         )
         if out.returncode:
-            raise FFmpegError(out.stderr)
+            raise FFmpegError(out.stderr, show_log)
 
     nbytes = utils.get_samplesize(shape, dtype)
 
@@ -75,33 +76,7 @@ def create(expr, *args, pix_fmt=None, vf=None, vframe=None, show_log=None, **kwa
     :return: image data, created by `bytes_to_video` plugin hook
     :rtype: object
 
-
-    Supported Video Source Filters
-    ------------------------------
-
-    =============  ==============================================================================
-    filter name    description
-    =============  ==============================================================================
-    "color"        uniformly colored frame
-    "allrgb"       frames of size 4096x4096 of all rgb colors
-    "allyuv"       frames of size 4096x4096 of all yuv colors
-    "gradients"    several gradients
-    "mandelbrot"   Mandelbrot set fractal
-    "mptestsrc"    various test patterns of the MPlayer test filter
-    "life"         life pattern based on John Conway’s life game
-    "haldclutsrc"  identity Hald CLUT
-    "testsrc"      test video pattern, showing a color pattern
-    "testsrc2"     another test video pattern, showing a color pattern
-    "rgbtestsrc"   RGB test pattern useful for detecting RGB vs BGR issues
-    "smptebars"    color bars pattern, based on the SMPTE Engineering Guideline EG 1-1990
-    "smptehdbars"  color bars pattern, based on the SMPTE RP 219-2002
-    "pal100bars"   a color bars pattern, based on EBU PAL recommendations with 100% color levels
-    "pal75bars"    a color bars pattern, based on EBU PAL recommendations with 75% color levels
-    "yuvtestsrc"   YUV test pattern. You should see a y, cb and cr stripe from top to bottom
-    "sierpinski"   Sierpinski carpet/triangle fractal
-    =============  ==============================================================================
-
-    https://ffmpeg.org/ffmpeg-filters.html#Video-Sources
+    See https://ffmpeg.org/ffmpeg-filters.html#Video-Sources for available video source filters
 
     """
 
@@ -142,12 +117,14 @@ def read(url, show_log=None, **options):
     """
 
     # get pix_fmt of the input file only if needed
+    pix_fmt_in = s_in = None
     if "pix_fmt" not in options and "pix_fmt_in" not in options:
-        info = probe.video_streams_basic(url, 0)[0]
-        pix_fmt_in = info["pix_fmt"]
-        s_in = (info["width"], info["height"])
-    else:
-        pix_fmt_in = s_in = None
+        try:
+            info = probe.video_streams_basic(url, 0)[0]
+            pix_fmt_in = info["pix_fmt"]
+            s_in = (info["width"], info["height"])
+        except:
+            pix_fmt_in = 'rgb24'
 
     input_options = utils.pop_extra_options(options, "_in")
 
@@ -205,14 +182,17 @@ def write(url, data, overwrite=None, show_log=None, **options):
 
     configure.build_basic_vf(ffmpeg_args, configure.check_alpha_change(ffmpeg_args, -1))
 
-    ffmpegprocess.run(
+    out = ffmpegprocess.run(
         ffmpeg_args,
         input=plugins.get_hook().video_bytes(obj=data),
         stdout=stdout,
         overwrite=overwrite,
-        capture_log=None if show_log else False,
+        capture_log=None if show_log else True,
     )
 
+    if out.returncode:
+        raise FFmpegError(out.stderr, show_log)
+
 
 def filter(expr, input, **options):
     """Filter image pixels.
