@@ -88,7 +88,7 @@ class SimpleReaderBase:
 
         self.samplesize = utils.get_samplesize(self.shape, self.dtype)
 
-        self.blocksize = blocksize or max(1024 ** 2 // self.samplesize, 1)
+        self.blocksize = blocksize or max(1024**2 // self.samplesize, 1)
         logging.debug("[reader main] completed init")
 
     def close(self):
@@ -146,10 +146,10 @@ class SimpleReaderBase:
         return self
 
     def __next__(self):
-        try:
-            return self.read(self.blocksize)
-        except:
+        F = self.read(self.blocksize)
+        if F is None:
             raise StopIteration
+        return F
 
     def readlog(self, n=None):
         if n is not None:
@@ -176,6 +176,7 @@ class SimpleReaderBase:
         logging.debug(f"[reader main] read {len(b)} bytes")
         if not len(b):
             self._proc.stdout.close()
+            return None
         return self._converter(b=b, shape=self.shape, dtype=self.dtype, squeeze=False)
 
     def readinto(self, array):
@@ -234,8 +235,7 @@ class SimpleVideoReader(SimpleReaderBase):
                 s_in = (info["width"], info["height"])
                 r_in = info["frame_rate"]
             except:
-                pix_fmt_in = 'rgb24'
-            
+                pix_fmt_in = "rgb24"
 
         if pix_fmt_in is None and pix_fmt is None:
             raise ValueError("pix_fmt must be specified.")
@@ -293,7 +293,7 @@ class SimpleAudioReader(SimpleReaderBase):
                 ac_in = info.get("channels", None)
                 ar_in = info.get("sample_rate", None)
             except:
-                sample_fmt_in = 's16'
+                sample_fmt_in = "s16"
 
         (
             self.dtype,
@@ -383,9 +383,9 @@ class SimpleWriterBase:
         """close the output stream"""
         if self._proc is None:
             return
-        self._proc.stdin.close()
-        self._proc.stderr.close()
+        self._proc.stdin.close()  # flushes the buffer first before closing
         self._proc.wait()
+        self._proc.stderr.close()
         self._logger.join()
 
     @property
@@ -461,6 +461,9 @@ class SimpleVideoWriter(SimpleWriterBase):
         **options,
     ):
         options["r_in"] = rate_in
+        if "r" not in options:
+            options["r"] = rate_in
+
         super().__init__(
             plugins.get_hook().video_bytes,
             url,
@@ -474,30 +477,40 @@ class SimpleVideoWriter(SimpleWriterBase):
     def _finalize(self, ffmpeg_args) -> None:
         inopts = ffmpeg_args["inputs"][0][1]
         inopts["f"] = "rawvideo"
-        if self.dtype_in is not None or self.shape_in is not None:
-            inopts["s"], inopts["pix_fmt"] = utils.guess_video_format(
-                (self.shape_in, self.dtype_in)
-            )
-            return True
 
         ready = "s" in inopts and "pix_fmt" in inopts
+
+        if not (ready or (self.dtype_in is None or self.shape_in is None)):
+            s, pix_fmt = utils.guess_video_format((self.shape_in, self.dtype_in))
+            if "s" not in inopts:
+                inopts["s"] = s
+            if "pix_fmt" not in inopts:
+                inopts["pix_fmt"] = pix_fmt
+            ready = True
+
         if ready:
+            # set basic video filter chain if related options are specified
             configure.build_basic_vf(
                 ffmpeg_args, configure.check_alpha_change(ffmpeg_args, -1)
             )
-        return
+        return ready
 
     def _finalize_with_data(self, data):
 
         ffmpeg_args = self._cfg["ffmpeg_args"]
         inopts = ffmpeg_args["inputs"][0][1]
         shape, dtype = plugins.get_hook().video_info(obj=data)
-        inopts["s"], inopts["pix_fmt"] = utils.guess_video_format(shape, dtype)
+        s, pix_fmt = utils.guess_video_format(shape, dtype)
 
         configure.build_basic_vf(
             ffmpeg_args, configure.check_alpha_change(ffmpeg_args, -1)
         )
 
+        if "s" not in inopts:
+            inopts["s"] = s
+        if "pix_fmt" not in inopts:
+            inopts["pix_fmt"] = pix_fmt
+
         self.shape_in = shape
         self.dtype_in = dtype
 
@@ -519,6 +532,9 @@ class SimpleAudioWriter(SimpleWriterBase):
         **options,
     ):
         options["ar_in"] = rate_in
+        if "ar" not in options:
+            options["ar"] = rate_in
+
         super().__init__(
             plugins.get_hook().audio_bytes,
             url,
@@ -530,14 +546,25 @@ class SimpleAudioWriter(SimpleWriterBase):
         )
 
     def _finalize(self, ffmpeg_args):
-        if self.dtype_in is not None or self.shape_in is not None:
+
+        # ffmpeg_args must have sample format & sampling rate specified
+        inopts = ffmpeg_args["inputs"][0][1]
+        ready = "sample_fmt" in inopts and "ac" in inopts
+
+        if not ready and (self.dtype_in is not None or self.shape_in is not None):
             inopts = ffmpeg_args["inputs"][0][1]
             inopts["sample_fmt"], inopts["ac"] = utils.guess_audio_format(
                 self.dtype_in, self.shape_in
             )
+            ready = True
+
+        if ready and not ("c:a" in inopts or "acodec" in inopts):
+            # fill audio codec and format options
             inopts["c:a"], inopts["f"] = utils.get_audio_codec(inopts["sample_fmt"])
-            return True
-        return False
+            if "acodec" in inopts:
+                del inopts["acodec"]
+
+        return ready
 
     def _finalize_with_data(self, data):
 
